@@ -15,18 +15,17 @@
 class CourseStub : public ICourse
 {
 public:
-    CourseStub(std::shared_ptr<ILanguage> language, QVector<std::shared_ptr<Unit>> units)
-        : m_language(language)
-        , m_units(units)
-    {
-    }
     ~CourseStub() override;
 
     static std::shared_ptr<ICourse> create(std::shared_ptr<ILanguage> language, QVector<std::shared_ptr<Unit>> units)
     {
         auto course = std::make_shared<CourseStub>(language, units);
         course->setSelf(course);
-        return std::static_pointer_cast<ICourse>(course);
+        auto self = std::static_pointer_cast<ICourse>(course);
+        for (const auto & unit : units ) {
+            unit->setCourse(self);
+        }
+        return self;
     }
 
     void setSelf(std::shared_ptr<ICourse> self) override
@@ -49,7 +48,7 @@ public:
     void setTitle(QString title)
     {
         m_title = title;
-        emit titleChanged();
+        Q_EMIT titleChanged();
     }
     QString i18nTitle() const override
     {
@@ -79,8 +78,14 @@ public:
         return QUrl();
     }
 
+    CourseStub(std::shared_ptr<ILanguage> language, QVector<std::shared_ptr<Unit>> units)
+        : m_language(language)
+        , m_units(units)
+    {
+    }
+
 private:
-    QString m_title {"title"};
+    QString m_title {QStringLiteral("title")};
     std::weak_ptr<ICourse> m_self;
     std::shared_ptr<ILanguage> m_language;
     QVector<std::shared_ptr<Unit>> m_units;
